import { html, when } from "@microsoft/fast-element";
import { Checkbox } from "./checkbox";
import { bool } from "../utilities";

export const CheckboxTemplate = html<Checkbox>`
    <template
        role="checkbox"
        $aria-checked="${x => bool(x.checked)}"
        $aria-required="${x => bool(x.required)}"
        $aria-disabled="${x => bool(x.disabled)}"
        $aria-readonly="${x => bool(x.readOnly)}"
        $tabindex="${x => (bool(x.disabled) ? null : 0)}"
        @keypress="${(x, c) => x.keypressHandler(c.event as KeyboardEvent)}"
        @click="${(x, c) => x.clickHandler(c.event as MouseEvent)}"
    >
    <div
        part="checkbox"
        class="checkbox"
    >
            <slot
                name="checked-indicator"
            >
                <svg
                    aria-hidden="true"
                    part="checked-indicator"
                    class="checked-indicator"
                    viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"
                >
                    <path
                        fill-rule="evenodd"
                        clip-rule="evenodd"
                        d="M8.143 12.6697L15.235 4.5L16.8 5.90363L8.23812 15.7667L3.80005 11.2556L5.27591 9.7555L8.143 12.6697Z"
                        />
                </svg>
            </slot>
            <slot
                name="indeterminate-indicator"
             >
                <div
                    part="indeterminate-indicator"
                    class="indeterminate-indicator"
                ></div>
             </slot>

    </div>
    ${when(
        x => x.childNodes.length,
        html`
        <label
            part="label"
            class="label"
        ><slot></slot></label>
    `
    )}
    </template>
`;
